pub enum Reinstall {
Always,
WhenMissing,
}Expand description
Whether an install replaces a runtime that is already there.
Variants
Always
Download and unpack even when the version is already installed.
WhenMissing
Leave an installed version alone.